#
# spec file for package python-psycopg
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-psycopg
# This needs to upgraded in lockstep with python-psycopg-c
Version:        3.2.6
Release:        1.1
Summary:        PostgreSQL database adapter for Python
License:        LGPL-3.0-only
URL:            https://psycopg.org/psycopg3/
Source:         https://github.com/psycopg/psycopg/archive/refs/tags/%{version}.tar.gz#/psycopg-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 49.2.0}
BuildRequires:  %{python_module wheel >= 0.37}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module typing-extensions >= 4.1}
BuildRequires:  %{python_module psycopg-c == %{version}}
# psycopg-pool has a different release schedule, version number is likely
# different
BuildRequires:  %{python_module psycopg-pool}
BuildRequires:  %{python_module anyio}
BuildRequires:  %{python_module mypy}
BuildRequires:  %{python_module pytest}
# /SECTION
BuildRequires:  fdupes
Requires:       python-psycopg-c == %{version}
Requires:       python-typing-extensions >= 4.1
Suggests:       python-dnspython >= 2.1
Suggests:       python-psycopg-pool
BuildArch:      noarch
%python_subpackages

%description
PostgreSQL database adapter for Python

%prep
%autosetup -p1 -n psycopg-%{version}

%build
pushd psycopg
%pyproject_wheel
popd

%install
pushd psycopg
%pyproject_install
popd
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitelib}/psycopg
%{python_sitelib}/psycopg-%{version}.dist-info

%changelog
* Wed Apr  9 2025 Antonio Larrosa <alarrosa@suse.com>
- update to 3.2.6:
  * Fix connection semantic when using
    target_session_attrs=prefer-standby (ticket #1021).
- update to 3.2.5:
  * 3x faster UUID loading thanks to C implementation
    (tickets #447, #998).
- update to 3.2.4:
  * Don’t lose notifies received whilst the notifies() iterator
    is not running (ticket #962).
  * Make sure that the notifies callback is called during the use
    of the notifies() generator (ticket #972).
  * Raise the correct error returned by the database (such as
    AdminShutdown or IdleInTransactionSessionTimeout) instead of
    a generic OperationalError when a server error causes a client
    disconnection (ticket #988).
  * Build macOS dependencies from sources instead using the
    Homebrew versions in order to avoid problems with
    MACOSX_DEPLOYMENT_TARGET (ticket #858).
  * Bump libpq to 17.2 in Linux and macOS binary packages.
  * Bump libpq to 16.4 in Windows binary packages, using the
    vcpkg library (ticket #966).
* Tue Nov 12 2024 Dirk Müller <dmueller@suse.com>
- update to 3.2.3:
  * Release binary packages including PostgreSQL 17 libpq
    (:ticket:`#852`).
  * Drop !TypeDef specifications as string from public modules,
    as they cannot be composed by users as !typing objects
    previously could (:ticket:`#860`).
  * Release Python 3.13 binary packages.
* Sat Aug 31 2024 Dirk Müller <dmueller@suse.com>
- update to 3.2.1:
  * Fix packaging metadata breaking [c], [binary] dependencies
  * Add support for integer, floating point, boolean NumPy scalar
    types (ticket #332).
  * Add timeout and stop_after parameters to Connection.notifies()
  * Allow dumpers to return None, to be converted to NULL (ticket
  * Add Raw query cursors to execute queries using placeholders in
    PostgreSQL format ($1, $2…) (tickets #560, #839).
  * Add capabilities object to inspect the libpq capabilities
  * Add scalar_row to return scalar values from a query
  * Add cancel_safe() for encrypted and non-blocking cancellation when
    using libpq v17. Use such method internally to implement
    KeyboardInterrupt and copy termination
  * The context parameter of sql objects as_string() and as_bytes()
    methods is now optional
  * Add set_autocommit() on sync connections, and similar transaction
    control methods available on the async connections.
  * Add a size parameter to stream() to enable results retrieval in
    chunks instead of row-by-row
- drop fix-pool-import.patch (upstream)
* Thu May 16 2024 Dirk Müller <dmueller@suse.com>
- update to 3.1.19:
  * Fix unaligned access undefined behaviour in C extension
  * Fix excessive stripping of error message prefixes
  * Allow to specify the connect_timeout connection parameter as
    float
  * Improve COPY performance on macOS
* Thu Mar 21 2024 Dirk Müller <dmueller@suse.com>
- update to 3.1.18:
  * Fix possible deadlock on pipeline exit (:ticket:`#685`).
  * Fix overflow loading large intervals in C module
  * Fix compatibility with musl libc distributions affected by
    CPython issue #65821
* Mon Jan 15 2024 Antonio Larrosa <alarrosa@suse.com>
- Use %%sle15_python_module_pythons
* Mon Jan 15 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.1.17:
  * Fix multiple connection attempts when a host name resolve to multiple
    IP addresses (:ticket:`699`).
  * Use `typing.Self` as a more correct return value annotation of context
    managers and other self-returning methods (see :ticket:`708`).
- Add patch fix-pool-import.patch:
  * Correct where we are importing from due to new pool release.
* Fri Jan  5 2024 Dirk Müller <dmueller@suse.com>
- update to 3.1.16:
  * Fix empty ports handling in async multiple connection attempts
* Thu Dec 14 2023 Dirk Müller <dmueller@suse.com>
- update to 3.1.15:
  * Fix use of ``service`` in connection string (regression in
    3.1.13, :ticket:`#694`).
  * Fix async connection to hosts resolving to multiple IP
    addresses (regression in 3.1.13, :ticket:`#695`).
  * Respect the :envvar:`PGCONNECT_TIMEOUT` environment variable
    to determine the connection timeout.
  * Fix :ref:`interaction with gevent <gevent>` (:ticket:`#527`).
  * Add support for PyPy (:ticket:`#686`).
* Fri Nov 24 2023 Antonio Larrosa <alarrosa@suse.com>
- Update to 3.1.13:
  * Raise DataError instead of whatever internal failure trying to
    dump a time object with with a tzinfo specified as ZoneInfo
    (ambiguous offset, see ticket #652).
  * Handle gracefully EINTR on signals instead of raising
    InterruptedError, consistently with PEP 475 guideline
    (ticket #667).
  * Fix support for connection strings with multiple hosts/ports
    and for the load_balance_hosts connection parameter
    (ticket #674).
  * Fix memory leak receiving notifications in Python
    implementation (ticket #679).
- Update to 3.1.12:
  * Fix possible hanging if a connection is closed while querying
    (ticket #608).
  * Fix memory leak when register_*() functions are called
    repeatedly (ticket #647).
  * Release Python 3.12 binary packages.
- Update to 3.1.11:
  * Avoid caching the parsing results of large queries to avoid
    excessive memory usage (ticket #628).
  * Fix integer overflow in C/binary extension with OID > 2^31
    (ticket #630).
  * Fix loading of intervals with days and months or years
    (ticket #643).
  * Work around excessive CPU usage on Windows (reported in
    ticket #645).
  * Fix building on Solaris and derivatives (ticket #632).
  * Fix possible lack of critical section guard in
    async executemany().
  * Fix missing pipeline fetch in async scroll().
  * Build binary packages with libpq 15.4, which allows
    group-readable permissions on the SSL certificate on the client
    (ticket #528).
- Update to 3.1.10
  * Allow JSON dumpers to dump bytes directly instead of str, for
    better compatibility with libraries like orjson and msgspec
    (ticket #569)
  * Fix prepared statement cache validation when exiting pipeline
    mode (or executemany()) in case an error occurred within the
    pipeline (ticket #585).
  * Fix connect() to avoid “leaking” an open PGconn attached to
    the OperationalError in case of connection failure.
    Error.pgconn is now a shallow copy of the real libpq
    connection, and the latter is closed before the exception
    propagates (ticket #565).
  * Fix possible (ignored) exception on objects deletion
    (ticket #591).
  * Don’t clobber a Python exception raised during COPY FROM with
    the resulting QueryCanceled raised as a consequence
    (ticket #593).
  * Fix resetting Connection.read_only and deferrable to their
    default value using None (ticket #612).
  * Add support for Python 3.12.
* Wed Jul 12 2023 Steve Kowalik <steven.kowalik@suse.com>
- Initial release of 3.1.9
